# GeoPlot

![](logo.jpg)

<a href="https://pypi.org/project/bas-geoplot/"><img src="https://img.shields.io/pypi/v/bas-geoplot" alt="PyPI">
<a href="https://github.com/antarctica/GeoPlot/issues"><img src="https://img.shields.io/github/issues/antarctica/GeoPlot" alt="Issues"></a>
<a href="https://github.com/antarctica/GeoPlot/blob/main/LICENSE"><img src="https://img.shields.io/github/license/antarctica/GeoPlot" alt="License"></a>

GeoPlot is an interactive and static plotting toolkit developed by members of the BAS Artificial
Intelligence Lab and designed to be used in combination with other software packages under development by the same team.

## Installation
The software package can be installed either from PyPI or by downloading the GitHub repo and installing from a local copy.

Installation from PyPI:
```
pip install bas-geoplot
```

Installation from source:
```
git clone https://github.com/Antarctica/Geoplot
pip install -e ./GeoPlot
```

Use of `-e` is optional, based on whether you want to be able to edit the installed copy of the package.

Some features of this software package require GDAL and Fiona to be installed, this requires additional steps during the installation process on Windows. These additional steps are as follows:

Windows only:
```
    pip install pipwin
    pipwin install gdal
    pipwin install fiona
    pipwin install cartopy
```

See the project's [PyPI](https://pypi.org/project/bas-geoplot/) page for more info.

## Command Line Interface

Once installed, bas-geoplot can be used to generate plots of geospatial data, including meshes generated by
[PolarRoute](https://github.com/antarctica/PolarRoute) or [MeshiPhi](https://github.com/antarctica/MeshiPhi). To generate an interactive plot from such a mesh:

```
plot_mesh <mesh.json>
```
optional arguments are:
```
-v '(turn on verbose logging)'
-o '(set output location for plot)'
-s '(create a static plot as opposed to an interactive html file)'
-t '(remove the title bar from the plot)'
-r '(plot an additional route from the given file)'
-a '(add directional arrows to all routes)'
-b '(create the plot without a basemap layer)'
```

## Development & Contributions
Development of software package is conducted by the [BAS AI Lab](https://www.bas.ac.uk/team/science-teams/ai-lab/).

For contributions and feature additions please contact [polarroute@bas.ac.uk](polarroute@bas.ac.uk).


## License
Distributed under the MIT license. See ``LICENSE`` for more information.

[version]: https://img.shields.io/GeoPlot/v/datadog-metrics.svg?style=flat-square
[downloads]: https://img.shields.io/GeoPlot/dm/datadog-metrics.svg?style=flat-square
